@@ -17,8 +17,8 @@ status = Release
 
 import serial
 import serial.tools.list_ports as ls_ports
-import cdbapi.config as config
-import cdbapi.common as cf
+import drivebox.config as config
+import drivebox.common as cf
 import time
 import math
 
