@@ -4,10 +4,6 @@ Created on Wed Sep 18 22:33:19 2019
 
 @author: lockhart
 """
-import numpy as np
-import re
-import random
-import logging
 
 #------------------------------------------------------------------------------
 def int_2_str(integer, amnt_digits, spacer="0"):
